==> v3.1.4.tar.gz: contextos/src/template/web.chat.header/language/zh-cn.js <==
Volcanos("user", {_trans: kit.Dict("_week_header", ["周日", "周一", "周二", "周三", "周四", "周五", "周六"],
	ice.LIST, "查看", ice.BACK, "返回", ice.HELP, "帮助",
	ctx.ACTION, "操作", ctx.RUN, "执行",
	mdb.CREATE, "创建", mdb.REMOVE, "删除", mdb.UPDATE, "更新",
	mdb.INSERT, "添加", mdb.DELETE, "删除", mdb.MODIFY, "编辑",
	mdb.REVERT, "恢复", mdb.PRUNES, "清理", mdb.PRUNE, "清理", mdb.EXPORT, "导出", mdb.IMPORT, "导入",
	mdb.SEARCH, "搜索", mdb.PLUGIN, "插件",
	mdb.PREV, "上一页", mdb.NEXT, "下一页",
	mdb.ENABLE, "启用", mdb.DISABLE, "禁用",
	mdb.RENAME, "重命名",
	web.CLEAR, "清空", web.REFRESH, "刷新",
	web.CANCEL, "取消", web.SUBMIT, "提交", web.CONFIRM, "确定",
	web.UPLOAD, "上传", web.DOWNLOAD, "下载", web.PREVIEW, "预览",
	web.SHARE, "共享", web.TOKEN, "令牌", web.GRANT, "授权",
	web.PORTAL, "官网", web.DESKTOP, "桌面", web.ADMIN, "后台", web.SPACE, "空间", web.DREAM, "空间", web.STORE, "商店", web.MATRIX, "矩阵",
	aaa.APPLY, "申请", aaa.LOGIN, "登录",
	cli.BEGIN, "开始", cli.END, "结束",
	cli.START, "启动", cli.RESTART, "重启", cli.STOP, "停止",
	cli.OPEN, "打开", cli.CLOSE, "关闭",
	cli.RUNTIME, "环境", cli.QRCODE, "二维码",
	cli.REBOOT, "重启", cli.BUILD, "构建", cli.DONE, "完成",
	nfs.SAVE, "保存", nfs.LOAD, "加载", nfs.TRASH, "清理",
	nfs.MODULE, "模块", nfs.VRESION, "版本", nfs.SOURCE, "源码", nfs.SCRIPT, "脚本",
	nfs.REPOS, "源码", nfs.CLONE, "克隆", nfs.PUSH, "上传", nfs.PULL, "下载",
	tcp.SEND, "发送",
	wiki.WORD, "文档",
	team.PLAN, "计划",
	code.VIMER, "编程", code.INNER, "代码", code.XTERM, "终端",
	code.COMPILE, "编译", code.UPGRADE, "升级", code.PUBLISH, "发布", code.INSTALL, "安装",
	html.HEIGHT, "高度", html.WIDTH, "宽度", html.SPEED, "速度", html.MARGIN, "边距",
	html.IFRAME, "预览",
	"Close", "关闭", "Close Other", "关闭其它", "Rename Tabs", "重命名",
	"more", "更多", "actions", "操作", "record1", "截图", "record2", "录屏",
	"play", "播放", "show", "预览", "exec", "输出", "full", "全屏",
	"logs", "日志", "conf", "配置", "configs", "配置", "inspect", "详情",
	"add", "添加", "opt", "优化", "fix", "修复",
	"status", "源码",
	"message", "聊天",
	"scan", "扫描",
	"sso", "登录",
	html.INPUT, kit.Dict(
		ice.POD, "空间", ice.CTX, "模块", ice.CMD, "命令", ice.HELP, "帮助",
		ctx.INDEX, "命令", ctx.ARGS, "参数", ctx.STYLE, "样式", ctx.ACTION, "操作", ctx.CMDS, "命令",
		ctx.COMMAND, "命令",
		mdb.TIME, "时间", mdb.HASH, "索引", mdb.ZONE, "分类", mdb.ID, "序号",
		mdb.TYPE, "类型", mdb.NAME, "名称", mdb.TEXT, "详情", mdb.ICON, "图标", mdb.ICONS, "图标",
		mdb.KEY, "字段", mdb.VALUE, "数据", mdb.STATUS, "状态", mdb.EXTRA, "其它",
		mdb.COUNT, "数量", mdb.TOTAL, "总数", mdb.ORDER, "排序", mdb.WEIGHT, "权重",
		mdb.SEARCH, "搜索",
		web.SERVER, "门户", web.WORKER, "空间",
		web.SERVE, "服务", web.DREAM, "空间", web.SPACE, "空间", web.TOKEN, "令牌", web.SHARE, "共享",
		web.ONLINE, "在线", web.OFFLINE, "离线",
		web.LINK, "链接", web.DOMAIN, "域名", web.FILTER, "筛选",
		web.PORTAL, "门户", web.VENDOR, "供应商", web.ORIGIN, "服务源",
		aaa.USERNICK, "昵称", aaa.USERNAME, "用户", aaa.PASSWORD, "密码", aaa.USERROLE, "角色", aaa.USERZONE, "单位",
		aaa.AVATAR, "头像", aaa.BACKGROUND, "背景",
		aaa.SESS, "会话", aaa.ROLE, "角色",
		aaa.LANGUAGE, "语言", aaa.COUNTRY, "国家", aaa.PROVINCE, "省份", aaa.CITY, "城市",
		aaa.EMAIL, "邮箱", aaa.MOBILE, "手机",
		aaa.IP, "地址", aaa.UA, "代理",
		gdb.SIGNAL, "信号",
		tcp.PROTO, "协议", tcp.HOST, "主机", tcp.PORT, "端口",
		tcp.SERVICE, "服务", tcp.HOSTNAME, "主机名",
		tcp.WIFI, "无线", tcp.SSID, "名称",
		nfs.DIR, "目录", nfs.DIR_ROOT, "目录",
		nfs.PATH, "路径", nfs.FILE, "文件", nfs.LINE, "行号", nfs.SIZE, "大小",
		nfs.REPOS, "仓库", nfs.MODULE, "模块", nfs.BRANCH, "分支", nfs.VERSION, "版本",
		nfs.SOURCE, "源码", nfs.BINARY, "镜像", nfs.SCRIPT, "脚本",
		nfs.IMAGE, "图片", nfs.TEMPLATE, "模板",
		cli.QRCODE, "二维码", cli.SYSTEM, "系统", cli.DAEMON, "守护",
		cli.START, "启动", cli.RESTART, "重启", cli.STOP, "停止", cli.COST, "耗时", cli.STEP, "步骤",
		cli.PID, "进程",
		team.ASSET, "资产",
		mall.GOODS, "商品", mall.PRICE, "单价", mall.UNITS, "单位", mall.AMOUNT, "总价",
		html.HEIGHT, "高度", html.WIDTH, "宽度", html.MARGIN, "边距", html.SPEED, "速度",
		"createdTime", "创建时间", "expiredTime", "过期时间",
		"commitTime", "发布时间", "compileTime", "编译时间", "bootTime", "启动时间",
		"commit", "提交", "message", "信息",
		"subject", "主题", "content", "内容",
		"hostport", "主机",
		"keyword", "关键字",
		"title", "标题",
		"dev", "主机",
		"nodename", "节点",
		"access", "访问",
		"arch", "架构", "kernel", "内核", "agent", "代理",
		"play", "演示",
		"msg", "报文", "log", kit.Dict(mdb.ID, "链路"),
		"machine", "机器", "params", "参数", "param", "参数",
		"click to detail", "点击查看详情",
		"endPoint", "节点", "secretId", "帐号", "secretKey", "密钥",
		"conf", "配置",
		"data", "数据",
	),
	html.VALUE, kit.Dict(
		"ENABLE", "启用", "DISABLE", "禁用",
	),
)})

==> v3.1.10.tar.gz: contextos/src/template/web.chat.header/language/zh-cn.js <==
Volcanos("user", {_trans: kit.Dict("_week_header", ["周日", "周一", "周二", "周三", "周四", "周五", "周六"],
	ice.LIST, "查看", ice.BACK, "返回", ice.HELP, "帮助",
	ice.FAILURE, "失败", ice.SUCCESS, "成功",
	ctx.ACTION, "操作", ctx.COMMAND, "命令", ctx.RUN, "执行",
	mdb.CREATE, "创建", mdb.REMOVE, "删除", mdb.MODIFY, "编辑",
	mdb.INSERT, "添加", mdb.DELETE, "删除", mdb.UPDATE, "更新",
	mdb.PRUNES, "清理", mdb.PRUNE, "清理", mdb.REVERT, "恢复",
	mdb.EXPORT, "导出", mdb.IMPORT, "导入",
	mdb.SEARCH, "搜索", mdb.PLUGIN, "插件",
	mdb.DETAIL, "详情", mdb.RENAME, "重命名",
	mdb.PREV, "上一页", mdb.NEXT, "下一页",
	mdb.ENABLE, "启用", mdb.DISABLE, "禁用",
	web.CLEAR, "清空", web.REFRESH, "刷新",
	web.CANCEL, "取消", web.SUBMIT, "提交", web.CONFIRM, "确定",
	web.UPLOAD, "上传", web.DOWNLOAD, "下载", web.PREVIEW, "预览",
	web.PORTAL, "官网", web.DESKTOP, "桌面", web.ADMIN, "后台", web.SPACE, "空间", web.DREAM, "空间",
	web.STORE, "商店", web.MATRIX, "矩阵", web.STUDIO, "工作台",
	web.SHARE, "共享", web.TOKEN, "令牌", web.GRANT, "授权",
	aaa.LOGIN, "登录", aaa.APPLY, "申请",
	
	cli.BEGIN, "开始", cli.END, "结束",
	cli.START, "启动", cli.RESTART, "重启", cli.STOP, "停止",
	cli.OPEN, "打开", cli.CLOSE, "关闭",
	cli.RUNTIME, "环境", cli.QRCODE, "二维码",
	cli.REBOOT, "重启", cli.BUILD, "构建", cli.DONE, "完成",
	nfs.SAVE, "保存", nfs.LOAD, "加载", nfs.TRASH, "清理",
	nfs.MODULE, "模块", nfs.VRESION, "版本", nfs.SOURCE, "源码", nfs.SCRIPT, "脚本",
	nfs.REPOS, "源码", nfs.CLONE, "克隆", nfs.PUSH, "上传", nfs.PULL, "下载",
	"moveto", "移动到",
	tcp.CLIENT, "客户端", tcp.SERVER, "服务器",
	tcp.SEND, "发送", tcp.RECV, "接收",
	
	wiki.WORD, "文档",
	code.VIMER, "编程", code.INNER, "代码", code.XTERM, "终端",
	code.COMPILE, "编译", code.UPGRADE, "升级", code.PUBLISH, "发布", code.INSTALL, "安装",
	chat.TUTOR, "向导", chat.MESSAGE, "聊天",
	team.PLAN, "计划",
	html.HEIGHT, "高度", html.WIDTH, "宽度", html.MARGIN, "边距", html.SPEED, "速度",
	html.IFRAME, "预览",
	
	"Close", "关闭", "Close Other", "关闭其它", "Rename Tabs", "重命名",
	"more", "更多", "actions", "操作", "record1", "截图", "record2", "录屏",
	"play", "播放", "show", "预览", "exec", "输出", "full", "全屏",
	"logs", "日志", "conf", "配置", "configs", "配置", "inspect", "详情",
	"add", "添加", "opt", "优化", "fix", "修复",
	"status", "源码",
	"doc", "文档",
	"sso", "登录",
	"not login: ", "没有登录",
	"not right: ", "没有权限",
	"company", "公司",
	"product", "产品",
	"switch", "切换",
	"scan", "扫描",
	
	html.INPUT, kit.Dict(
		ice.POD, "空间", ice.CTX, "模块", ice.CMD, "命令", ice.HELP, "帮助",
		ctx.INDEX, "命令", ctx.ARGS, "参数", ctx.STYLE, "样式", ctx.ACTION, "操作", ctx.CMDS, "命令", ctx.COMMAND, "命令",
		mdb.TIME, "时间", mdb.HASH, "索引", mdb.ZONE, "分类", mdb.ID, "序号",
		mdb.TYPE, "类型", mdb.NAME, "名称", mdb.TEXT, "详情", mdb.ICON, "图标", mdb.ICONS, "图标",
		mdb.KEY, "字段", mdb.VALUE, "数据", mdb.STATUS, "状态", mdb.EXTRA, "其它",
		mdb.COUNT, "数量", mdb.TOTAL, "总数", mdb.ORDER, "排序", mdb.WEIGHT, "权重",
		mdb.ENABLE, "启用", mdb.DISABLE, "禁用",
		mdb.SEARCH, "搜索", mdb.NICK, "昵称",
		web.SERVER, "门户", web.WORKER, "空间",
		web.SERVE, "服务", web.DREAM, "空间", web.SPACE, "空间", web.TOKEN, "令牌", web.SHARE, "共享",
		web.ONLINE, "在线", web.OFFLINE, "离线",
		web.LINK, "链接", web.DOMAIN, "域名", web.FILTER, "筛选",
		web.PORTAL, "门户", web.VENDOR, "供应商", web.ORIGIN, "服务源",
		aaa.USERNICK, "昵称", aaa.USERNAME, "用户", aaa.PASSWORD, "密码", aaa.USERROLE, "角色", aaa.USERZONE, "单位",
		aaa.AVATAR, "头像", aaa.BACKGROUND, "背景",
		aaa.SESS, "会话", aaa.ROLE, "角色",
		aaa.LANGUAGE, "语言", aaa.COUNTRY, "国家", aaa.PROVINCE, "省份", aaa.CITY, "城市",
		aaa.EMAIL, "邮箱", aaa.MOBILE, "手机",
		aaa.IP, "地址", aaa.UA, "代理",
		aaa.LOCATION, "位置", aaa.LONGITUDE, "经度", aaa.LATITUDE, "纬度",
		gdb.SIGNAL, "信号",
		tcp.PROTO, "协议", tcp.HOST, "主机", tcp.PORT, "端口",
		tcp.SERVICE, "服务", tcp.HOSTNAME, "主机名",
		tcp.WIFI, "无线", tcp.SSID, "名称",
		nfs.DIR, "目录", nfs.DIR_ROOT, "目录",
		nfs.PATH, "路径", nfs.FILE, "文件", nfs.LINE, "行号", nfs.SIZE, "大小",
		nfs.REPOS, "仓库", nfs.MODULE, "模块", nfs.BRANCH, "分支",
		nfs.VERSION, "版本",
		nfs.SOURCE, "源码", nfs.BINARY, "镜像", nfs.SCRIPT, "脚本",
		nfs.IMAGE, "图片", nfs.TEMPLATE, "模板",
		cli.QRCODE, "二维码", cli.SYSTEM, "系统", cli.DAEMON, "守护",
		cli.START, "启动", cli.RESTART, "重启", cli.STOP, "停止", cli.COST, "耗时", cli.STEP, "步骤",
		cli.PID, "进程",
		team.ASSET, "资产",
		mall.GOODS, "商品", mall.PRICE, "单价", mall.UNITS, "单位", mall.AMOUNT, "总价",
		html.HEIGHT, "高度", html.WIDTH, "宽度", html.MARGIN, "边距", html.SPEED, "速度",
		"createdTime", "创建时间", "expiredTime", "过期时间",
		"commitTime", "发布时间", "compileTime", "编译时间", "bootTime", "启动时间",
		"commit", "提交", "message", "信息",
		"subject", "主题", "content", "内容",
		"hostport", "主机",
		"keyword", "关键字",
		"title", "标题",
		"group", "分组",
		"color", "颜色",
		"dev", "主机",
		"nodename", "节点",
		"access", "访问",
		"arch", "架构", "kernel", "内核", "agent", "代理",
		"play", "演示",
		"msg", "报文", "log", kit.Dict(mdb.ID, "链路"),
		"machine", "机器", "params", "参数", "param", "参数",
		"click to detail", "点击查看详情",
		"endPoint", "节点", "secretId", "帐号", "secretKey", "密钥",
		"conf", "配置",
		"data", "数据",
		"product", "产品",
		"company", "公司",
	),
	html.VALUE, kit.Dict(
		"ENABLE", "启用", "DISABLE", "禁用",
	),
)})
